==> ejc-jltest-impl-3.0.0-20240328.015927-125-sources.jar: com/ejianc/business/jltest/margin/service/impl/DirectEmployeeBpmServiceImpl.java <==
package com.ejianc.business.jltest.margin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.jltest.margin.bean.*;
import com.ejianc.business.jltest.margin.controller.DirectEmployeeController;
import com.ejianc.business.jltest.margin.service.*;
import com.ejianc.business.jltest.margin.vo.DirectAllocationRecordVO;
import com.ejianc.business.jltest.margin.vo.DirectLedgeVO;
import com.ejianc.business.jltest.margin.vo.DirectPaidEmployeeVO;
import com.ejianc.business.jltest.margin.vo.DirectPaidRecordVO;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.vo.EmployeeVO;
import com.ejianc.foundation.permission.api.IRoleApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("directEmployee")
public class DirectEmployeeBpmServiceImpl implements ICommonBusinessService {

    @Autowired
    private IDirectEmployeeService directEmployeeService;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IEmployeeApi employeeApi;
    @Autowired
    private IRoleApi roleApi;
    @Autowired
    private IDirectLedgeService directLedgeService;
    @Autowired
    private IMoneyRefundService moneyRefundService;
    @Autowired
    private IRiskPayConfirmationService riskPayConfirmationService;
    @Autowired
    private IInspiritLossService inspiritLossService;
    @Autowired
    private IInspiritLossDetailService inspiritLossDetailService;

    private static final String BILL_CODE = "DIRECT_EMPLOYEE_CODE";//此处需要根据实际修改

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批后回调
     *
     * @param billId       //单据id
     * @param state        //单据状态
     * @param billTypeCode //单据类型code
     * @param taskId       //该流程id
     * @param isEnd        //该节点是否结束
     * @return
     */
    @Override
    public CommonResponse<String> afterInApprovalBack(Long billId, Integer state, String billTypeCode, String taskId, Boolean isEnd, String sign, Map<String, Object> other) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        DirectEmployeeEntity directEmployee = directEmployeeService.selectById(billId);
        DirectLedgeVO saveOrUpdateVO = new DirectLedgeVO();
        saveOrUpdateVO.setOrgId(directEmployee.getOrgId());
        saveOrUpdateVO.setOrgName(directEmployee.getOrgName());
        saveOrUpdateVO.setOrgCode(directEmployee.getOrgCode());
        saveOrUpdateVO.setYear(directEmployee.getYear());
        saveOrUpdateVO.setPayableMny(directEmployee.getEmployeeMny());
        saveOrUpdateVO.setDirectPaidRecordList(new ArrayList<>());
        saveOrUpdateVO.setAccumulatedMny(new BigDecimal(0));
        saveOrUpdateVO.setReturnMny(new BigDecimal(0));
        saveOrUpdateVO.setAllotmentMny(new BigDecimal(0));
        saveOrUpdateVO.setDirectPaidEmployeeList(new ArrayList<>());
        saveOrUpdateVO.setDirectAllocationRecordList(new ArrayList<>());
        for (DirectEmployeeDetailEntity employee : directEmployee.getDetailList()) {
            DirectPaidEmployeeVO paidEmployee = new DirectPaidEmployeeVO();
            EmployeeVO data = employeeApi.getById(employee.getEmployeeId()).getData();
            paidEmployee.setName(data.getName());
            paidEmployee.setRole(data.getRoleName());
            paidEmployee.setPhone(data.getMobilePhone());
            paidEmployee.setPayableMny(employee.getMarginMny());
            paidEmployee.setActualMny(employee.getMarginActual());
            paidEmployee.setActualRatio(employee.getMarginRatio());
            paidEmployee.setStandardCode(directEmployee.getStandardCode());
            paidEmployee.setAccumulatedPaidMny(new BigDecimal(0));
            paidEmployee.setAccumulatedReturnMny(new BigDecimal(0));
            paidEmployee.setAllotmentMny(new BigDecimal(0));
            paidEmployee.setAllotmentRatio(new BigDecimal(0));
            paidEmployee.setInTime(new Date());
            saveOrUpdateVO.getDirectPaidEmployeeList().add(paidEmployee);
            List<MoneyRefundEntity> moneyRefundList = moneyRefundService.list(new QueryWrapper<MoneyRefundEntity>().eq("employee_schedules_id", employee.getId()));
            for (MoneyRefundEntity moneyRefund : moneyRefundList) {
                DirectPaidRecordVO directPaidRecord = new DirectPaidRecordVO();
                directPaidRecord.setStandardCode(moneyRefund.getBillCode());
                directPaidRecord.setEmployeeId(moneyRefund.getEmployeeId());
                directPaidRecord.setEmployeeName(moneyRefund.getEmployeeName());
                directPaidRecord.setName(moneyRefund.getEmployeeName());
                directPaidRecord.setRecodType(moneyRefund.getType());
                directPaidRecord.setRecordMny(moneyRefund.getCurrentPeriodActualDue());
                directPaidRecord.setRecordTime(moneyRefund.getCreateTime());
                directPaidRecord.setRole(employee.getRoleName());
                directPaidRecord.setPhone(employee.getPhone());
                paidEmployee.setAccumulatedReturnMny(paidEmployee.getAccumulatedReturnMny().add(directPaidRecord.getRecordMny()));
                saveOrUpdateVO.getDirectPaidRecordList().add(directPaidRecord);
            }
            List<RiskPayConfirmationEntity> riskPayConfirmationList = riskPayConfirmationService.list(new QueryWrapper<RiskPayConfirmationEntity>().eq("employee_detail_id", employee.getId()));
            for (RiskPayConfirmationEntity payConfirmation : riskPayConfirmationList) {
                DirectPaidRecordVO directPaidRecord = new DirectPaidRecordVO();
                directPaidRecord.setStandardCode(payConfirmation.getBillCode());
                directPaidRecord.setEmployeeId(payConfirmation.getEmployeeId());
                directPaidRecord.setEmployeeName(payConfirmation.getEmployeeName());
                directPaidRecord.setName(payConfirmation.getEmployeeName());
                directPaidRecord.setRecodType(payConfirmation.getType());
                directPaidRecord.setRecordMny(payConfirmation.getCurrentPaymentAmount());
                directPaidRecord.setRecordTime(payConfirmation.getPaymentDate());
                directPaidRecord.setRole(employee.getRoleName());
                directPaidRecord.setPhone(employee.getPhone());
                paidEmployee.setAccumulatedPaidMny(paidEmployee.getAccumulatedPaidMny().add(directPaidRecord.getRecordMny()));
                saveOrUpdateVO.getDirectPaidRecordList().add(directPaidRecord);
            }

            List<InspiritLossDetailEntity> lossDetailList = inspiritLossDetailService.list(new QueryWrapper<InspiritLossDetailEntity>().eq("detail_id", employee.getId()));
            for (InspiritLossDetailEntity lossDetail : lossDetailList) {
                InspiritLossEntity loss = inspiritLossService.getById(lossDetail.getInspiritId());
                DirectAllocationRecordVO allocationRecord = new DirectAllocationRecordVO();
                allocationRecord.setAllocationCode(loss.getBillCode());
                allocationRecord.setName(employee.getEmployeeName());
                allocationRecord.setRole(employee.getRoleName());
                allocationRecord.setPhone(employee.getPhone());
                allocationRecord.setRecordMny(lossDetail.getDetailAssessment());
                allocationRecord.setEmployeeId(loss.getEmployeeId());
                allocationRecord.setEmployeeName(loss.getEmployeeName());
                allocationRecord.setRecordTime(loss.getCreateTime());
                paidEmployee.setAllotmentMny(paidEmployee.getAllotmentMny().add(allocationRecord.getRecordMny()));
                paidEmployee.setAllotmentRatio(paidEmployee.getAllotmentRatio().add(lossDetail.getDetailAssessPercent()));
                saveOrUpdateVO.getDirectAllocationRecordList().add(allocationRecord);
            }
            saveOrUpdateVO.setAccumulatedMny(saveOrUpdateVO.getAccumulatedMny().add(paidEmployee.getAccumulatedPaidMny()));
            saveOrUpdateVO.setReturnMny(saveOrUpdateVO.getReturnMny().add(paidEmployee.getAccumulatedReturnMny()));
            saveOrUpdateVO.setAllotmentMny(saveOrUpdateVO.getAllotmentMny().add(paidEmployee.getAllotmentMny()));
        }


        DirectLedgeEntity entity = BeanMapper.map(saveOrUpdateVO, DirectLedgeEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        directLedgeService.saveOrUpdate(entity, false);
        DirectLedgeVO vo = BeanMapper.map(entity, DirectLedgeVO.class);
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}

==> ejc-jltest-impl-3.0.0-20240328.061301-132-sources.jar: com/ejianc/business/jltest/margin/service/impl/DirectEmployeeBpmServiceImpl.java <==
package com.ejianc.business.jltest.margin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.jltest.margin.bean.*;
import com.ejianc.business.jltest.margin.controller.DirectEmployeeController;
import com.ejianc.business.jltest.margin.service.*;
import com.ejianc.business.jltest.margin.vo.DirectAllocationRecordVO;
import com.ejianc.business.jltest.margin.vo.DirectLedgeVO;
import com.ejianc.business.jltest.margin.vo.DirectPaidEmployeeVO;
import com.ejianc.business.jltest.margin.vo.DirectPaidRecordVO;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.vo.EmployeeVO;
import com.ejianc.foundation.permission.api.IRoleApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("directEmployee")
public class DirectEmployeeBpmServiceImpl implements ICommonBusinessService {

    @Autowired
    private IDirectEmployeeService directEmployeeService;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IEmployeeApi employeeApi;
    @Autowired
    private IRoleApi roleApi;
    @Autowired
    private IDirectLedgeService directLedgeService;
    @Autowired
    private IMoneyRefundService moneyRefundService;
    @Autowired
    private IRiskPayConfirmationService riskPayConfirmationService;
    @Autowired
    private IInspiritLossService inspiritLossService;
    @Autowired
    private IInspiritLossDetailService inspiritLossDetailService;

    private static final String BILL_CODE = "DIRECT_EMPLOYEE_CODE";//此处需要根据实际修改

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {

        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批后回调
     *
     * @param billId       //单据id
     * @param state        //单据状态
     * @param billTypeCode //单据类型code
     * @param taskId       //该流程id
     * @param isEnd        //该节点是否结束
     * @return
     */
    @Override
    public CommonResponse<String> afterInApprovalBack(Long billId, Integer state, String billTypeCode, String taskId, Boolean isEnd, String sign, Map<String, Object> other) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        DirectEmployeeEntity directEmployee = directEmployeeService.selectById(billId);
        DirectLedgeVO saveOrUpdateVO = new DirectLedgeVO();
        saveOrUpdateVO.setDirectEmployeeId(billId);
        saveOrUpdateVO.setOrgId(directEmployee.getOrgId());
        saveOrUpdateVO.setOrgName(directEmployee.getOrgName());
        saveOrUpdateVO.setOrgCode(directEmployee.getOrgCode());
        saveOrUpdateVO.setYear(directEmployee.getYear());
        saveOrUpdateVO.setPayableMny(directEmployee.getEmployeeMny());
        saveOrUpdateVO.setDirectPaidRecordList(new ArrayList<>());
        saveOrUpdateVO.setAccumulatedMny(new BigDecimal(0));
        saveOrUpdateVO.setReturnMny(new BigDecimal(0));
        saveOrUpdateVO.setAllotmentMny(new BigDecimal(0));
        saveOrUpdateVO.setDirectPaidEmployeeList(new ArrayList<>());
        saveOrUpdateVO.setDirectAllocationRecordList(new ArrayList<>());
        saveOrUpdateVO.setActualMny(directEmployee.getEmployeeActualMny());
        for (DirectEmployeeDetailEntity employee : directEmployee.getDetailList()) {
            DirectPaidEmployeeVO paidEmployee = new DirectPaidEmployeeVO();
            EmployeeVO data = employeeApi.getById(employee.getEmployeeId()).getData();
            paidEmployee.setName(data.getName());
            paidEmployee.setRole(data.getRoleName());
            paidEmployee.setPhone(data.getMobilePhone());
            paidEmployee.setPayableMny(employee.getMarginMny());
            paidEmployee.setActualMny(employee.getMarginActual());
            paidEmployee.setActualRatio(employee.getMarginRatio());
            paidEmployee.setStandardCode(directEmployee.getStandardCode());
            paidEmployee.setAccumulatedPaidMny(new BigDecimal(0));
            paidEmployee.setAccumulatedReturnMny(new BigDecimal(0));
            paidEmployee.setAllotmentMny(new BigDecimal(0));
            paidEmployee.setAllotmentRatio(new BigDecimal(0));
            paidEmployee.setInTime(new Date());
            saveOrUpdateVO.getDirectPaidEmployeeList().add(paidEmployee);
            List<MoneyRefundEntity> moneyRefundList = moneyRefundService.list(new QueryWrapper<MoneyRefundEntity>().eq("employee_schedules_id", employee.getId()));
            for (MoneyRefundEntity moneyRefund : moneyRefundList) {
                DirectPaidRecordVO directPaidRecord = new DirectPaidRecordVO();
                directPaidRecord.setStandardCode(moneyRefund.getBillCode());
                directPaidRecord.setEmployeeId(moneyRefund.getEmployeeId());
                directPaidRecord.setEmployeeName(moneyRefund.getEmployeeName());
                directPaidRecord.setName(moneyRefund.getEmployeeName());
                directPaidRecord.setRecodType(moneyRefund.getType());
                directPaidRecord.setRecordMny(moneyRefund.getCurrentPeriodActualDue());
                directPaidRecord.setRecordTime(moneyRefund.getCreateTime());
                directPaidRecord.setRole(employee.getRoleName());
                directPaidRecord.setPhone(employee.getPhone());
                paidEmployee.setAccumulatedReturnMny(paidEmployee.getAccumulatedReturnMny().add(directPaidRecord.getRecordMny()));
                saveOrUpdateVO.getDirectPaidRecordList().add(directPaidRecord);
            }
            List<RiskPayConfirmationEntity> riskPayConfirmationList = riskPayConfirmationService.list(new QueryWrapper<RiskPayConfirmationEntity>().eq("employee_detail_id", employee.getId()));
            for (RiskPayConfirmationEntity payConfirmation : riskPayConfirmationList) {
                DirectPaidRecordVO directPaidRecord = new DirectPaidRecordVO();
                directPaidRecord.setStandardCode(payConfirmation.getBillCode());
                directPaidRecord.setEmployeeId(payConfirmation.getEmployeeId());
                directPaidRecord.setEmployeeName(payConfirmation.getEmployeeName());
                directPaidRecord.setName(payConfirmation.getEmployeeName());
                directPaidRecord.setRecodType(payConfirmation.getType());
                directPaidRecord.setRecordMny(payConfirmation.getCurrentPaymentAmount());
                directPaidRecord.setRecordTime(payConfirmation.getPaymentDate());
                directPaidRecord.setRole(employee.getRoleName());
                directPaidRecord.setPhone(employee.getPhone());
                paidEmployee.setAccumulatedPaidMny(paidEmployee.getAccumulatedPaidMny().add(directPaidRecord.getRecordMny()));
                saveOrUpdateVO.getDirectPaidRecordList().add(directPaidRecord);
            }

            List<InspiritLossDetailEntity> lossDetailList = inspiritLossDetailService.list(new QueryWrapper<InspiritLossDetailEntity>().eq("detail_id", employee.getId()));
            for (InspiritLossDetailEntity lossDetail : lossDetailList) {
                InspiritLossEntity loss = inspiritLossService.getById(lossDetail.getInspiritId());
                DirectAllocationRecordVO allocationRecord = new DirectAllocationRecordVO();
                allocationRecord.setAllocationCode(loss.getBillCode());
                allocationRecord.setName(employee.getEmployeeName());
                allocationRecord.setRole(employee.getRoleName());
                allocationRecord.setPhone(employee.getPhone());
                allocationRecord.setRecordMny(lossDetail.getDetailAssessment());
                allocationRecord.setEmployeeId(loss.getEmployeeId());
                allocationRecord.setEmployeeName(loss.getEmployeeName());
                allocationRecord.setRecordTime(loss.getCreateTime());
                paidEmployee.setAllotmentMny(paidEmployee.getAllotmentMny().add(allocationRecord.getRecordMny()));
                paidEmployee.setAllotmentRatio(paidEmployee.getAllotmentRatio().add(lossDetail.getDetailAssessPercent()));
                saveOrUpdateVO.getDirectAllocationRecordList().add(allocationRecord);
            }
            saveOrUpdateVO.setAccumulatedMny(saveOrUpdateVO.getAccumulatedMny().add(paidEmployee.getAccumulatedPaidMny()));
            saveOrUpdateVO.setReturnMny(saveOrUpdateVO.getReturnMny().add(paidEmployee.getAccumulatedReturnMny()));
            saveOrUpdateVO.setAllotmentMny(saveOrUpdateVO.getAllotmentMny().add(paidEmployee.getAllotmentMny()));
        }


        DirectLedgeEntity entity = BeanMapper.map(saveOrUpdateVO, DirectLedgeEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        directLedgeService.saveOrUpdate(entity, false);
        DirectLedgeVO vo = BeanMapper.map(entity, DirectLedgeVO.class);
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        directLedgeService.remove(new QueryWrapper<DirectLedgeEntity>().eq("direct_employee_id", billId));
        return CommonResponse.success();

    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}
